#ifndef MCPARTICLE_H
#define MCPARTICLE_H 1

#include <Math/Point3D.h>
#include "Object.hpp"

namespace corryvreckan {
    /**
     * @ingroup Objects
     * @brief Monte Carlo particle from simulation
     */
    class MCParticle : public Object {

    public:
        // Constructors and destructors
        MCParticle() = default;
        MCParticle(std::string detectorID,
                   int particle_id,
                   ROOT::Math::XYZPoint local_start_point,
                   ROOT::Math::XYZPoint local_end_point,
                   double timestamp)
            : Object(detectorID, timestamp), m_particle_id(particle_id), m_local_start_point(local_start_point),
              m_local_end_point(local_end_point) {}

        /**
         * @brief Static member function to obtain base class for storage on the clipboard.
         * This method is used to store objects from derived classes under the typeid of their base classes
         *
         * @warning This function should not be implemented for derived object classes
         *
         * @return Class type of the base object
         */
        static std::type_index getBaseType() { return typeid(MCParticle); }

        // Member functions
        int getID() const { return m_particle_id; }
        ROOT::Math::XYZPoint getLocalStart() const { return m_local_start_point; }
        ROOT::Math::XYZPoint getLocalEnd() const { return m_local_end_point; }

    private:
        int m_particle_id;
        ROOT::Math::XYZPoint m_local_start_point;
        ROOT::Math::XYZPoint m_local_end_point;

        // ROOT I/O class definition - update version number when you change this class!
        ClassDef(MCParticle, 3)
    };

    // Vector type declaration
    using MCParticleVector = std::vector<MCParticle*>;
} // namespace corryvreckan

#endif // MCPARTICLE_H
